pub struct Region {
pub center: Coordinate,
pub latitude_delta: f64,
pub longitude_delta: f64,
}Expand description
A map region defined by a center coordinate and span.
Fields
center: CoordinateThe center coordinate of the region.
latitude_delta: f64The north-to-south span in degrees.
longitude_delta: f64The east-to-west span in degrees.
Implementations
Sourceimpl Region
impl Region
Sourcepub const fn new(
center: Coordinate,
latitude_delta: f64,
longitude_delta: f64,
) -> Self
pub const fn new( center: Coordinate, latitude_delta: f64, longitude_delta: f64, ) -> Self
Creates a new region.
Sourcepub const fn from_coordinate(coordinate: Coordinate) -> Self
pub const fn from_coordinate(coordinate: Coordinate) -> Self
Creates a region from a coordinate with default zoom.